@@ -9,24 +9,24 @@ class GroupMixIn:
         The results can be filtered by different parameters such as group name or origin.
 
         Args:
-            name: (optional) Group name to filter by
-            mail: (optional) Group email to filter by
-            role: (optional) Group role to filter by
-            origin: (optional) Group origin to filter by (ad or sisense)
-            ids: (optional) Array of group IDs to filter by
-            fields: (optional) Whitelist of fields to return for each document.
+            name (str): (Optional) Group name to filter by
+            mail (str): (Optional) Group email to filter by
+            role (str): (Optional) Group role to filter by
+            origin (str): (Optional) Group origin to filter by (ad or sisense)
+            ids (list[str]): (Optional) Array of group IDs to filter by
+            fields (list[str]): (Optional) Whitelist of fields to return for each document.
                 Fields can also define which fields to exclude by prefixing field names with -
-            sort: (optional) Field by which the results should be sorted.
+            sort (str): (Optional) Field by which the results should be sorted.
                 Ascending by default, descending if prefixed by -
-            skip: (optional) Number of results to skip from the start of the data set.
+            skip (int): (Optional) Number of results to skip from the start of the data set.
                 Skip is to be used with the limit parameter for paging
-            limit: (optional) How many results should be returned.
+            limit (int): (Optional) How many results should be returned.
                 limit is to be used with the skip parameter for paging
-            expand: (optional) List of fields that should be expanded (substitures their IDs with actual objects).
+            expand (list[str]): (Optional) List of fields that should be expanded
                 May be nested using the resource.subResource format
 
         Returns:
-            Array of found groups
+            list[Group]: The found groups
         """
 
         query_params = {
@@ -48,21 +48,31 @@ class GroupMixIn:
             ret_arr.append(PySenseGroup.Group(self, group))
         return ret_arr
 
-
     def get_group_by_id(self, group_id):
-        """Get a group by id"""
+        """Get a group by id
+
+        Args:
+            group_id (str): The id of the group to look for
+
+        Returns:
+            Group: The group with the given id
+        """
+
         if group_id is None:
             return None
         resp_json = self.connector.rest_call('get', 'api/groups/{}'.format(group_id))
         return PySenseGroup.Group(self, resp_json)
 
-
     def get_groups_by_name(self, group_names):
         """Returns an array of groups matching the given names
 
         Args:
-            group_names: One to many group names
+            group_names (list[str]): Group names to look for
+
+        Returns:
+            list[Group]: Groups with the given names
         """
+
         if group_names is None:
             return []
 
@@ -78,11 +88,12 @@ class GroupMixIn:
         """Add groups with given names.
 
         Args:
-            names: One to many names
+            names (str): The names of the new groups
 
         Returns:
-            Array of new groups
+            list[Group]: The new groups
         """
+
         ret_arr = []
         for name in PySenseUtils.make_iterable(names):
             payload = {'name': name}
@@ -94,7 +105,8 @@ class GroupMixIn:
         """Delete groups.
 
         Args:
-            groups: One to many groups to delete
+            groups (list[Group]): Groups to delete
         """
+
         for group in PySenseUtils.make_iterable(groups):
             self.connector.rest_call('delete', 'api/groups/{}'.format(group.get_id()))
